var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { globby } from 'globby';
import { defaultIgnoreList } from '../../config/defaultIgnore.js';
import { logger } from '../../shared/logger.js';
import { sortPaths } from './filePathSort.js';
export const searchFiles = (rootDir, config) => __awaiter(void 0, void 0, void 0, function* () {
    const includePatterns = config.include.length > 0 ? config.include : ['**/*'];
    try {
        const [ignorePatterns, ignoreFilePatterns] = yield Promise.all([
            getIgnorePatterns(rootDir, config),
            getIgnoreFilePatterns(config),
        ]);
        logger.trace('Include patterns:', includePatterns);
        logger.trace('Ignore patterns:', ignorePatterns);
        logger.trace('Ignore file patterns:', ignoreFilePatterns);
        const filePaths = yield globby(includePatterns, {
            cwd: rootDir,
            ignore: [...ignorePatterns],
            ignoreFiles: [...ignoreFilePatterns],
            onlyFiles: true,
            absolute: false,
            dot: true,
            followSymbolicLinks: false,
        });
        logger.trace(`Filtered ${filePaths.length} files`);
        const sortedPaths = sortPaths(filePaths);
        return sortedPaths;
    }
    catch (error) {
        if (error instanceof Error) {
            logger.error('Error filtering files:', error.message);
            throw new Error(`Failed to filter files in directory ${rootDir}. Reason: ${error.message}`);
        }
        logger.error('An unexpected error occurred:', error);
        throw new Error('An unexpected error occurred while filtering files.');
    }
});
export const parseIgnoreContent = (content) => {
    if (!content)
        return [];
    return content.split('\n').reduce((acc, line) => {
        const trimmedLine = line.trim();
        if (trimmedLine && !trimmedLine.startsWith('#')) {
            acc.push(trimmedLine);
        }
        return acc;
    }, []);
};
export const getIgnoreFilePatterns = (config) => __awaiter(void 0, void 0, void 0, function* () {
    const ignoreFilePatterns = [];
    if (config.ignore.useGitignore) {
        ignoreFilePatterns.push('**/.gitignore');
    }
    ignoreFilePatterns.push('**/.repomixignore');
    return ignoreFilePatterns;
});
export const getIgnorePatterns = (rootDir, config) => __awaiter(void 0, void 0, void 0, function* () {
    const ignorePatterns = new Set();
    // Add default ignore patterns
    if (config.ignore.useDefaultPatterns) {
        logger.trace('Adding default ignore patterns');
        for (const pattern of defaultIgnoreList) {
            ignorePatterns.add(pattern);
        }
    }
    // Add repomix output file
    if (config.output.filePath) {
        logger.trace('Adding output file to ignore patterns:', config.output.filePath);
        ignorePatterns.add(config.output.filePath);
    }
    // Add custom ignore patterns
    if (config.ignore.customPatterns) {
        logger.trace('Adding custom ignore patterns:', config.ignore.customPatterns);
        for (const pattern of config.ignore.customPatterns) {
            ignorePatterns.add(pattern);
        }
    }
    return Array.from(ignorePatterns);
});
//# sourceMappingURL=fileSearch.js.map